@@ -19,6 +19,7 @@ import time
 
 from keystoneclient.openstack.common.apiclient import exceptions
 import keystoneclient.v2_0.client as ksclient
+from os_cloud_config.utils import clients
 
 LOG = logging.getLogger(__name__)
 
@@ -104,7 +105,7 @@ SERVICES = {
 
 def initialize(host, admin_token, admin_email, admin_password,
                region='regionOne', ssl=None, public=None, user='root',
-               timeout=600, poll_interval=10):
+               timeout=600, poll_interval=10, pki_setup=True):
     """Perform post-heat initialization of Keystone.
 
     :param host: ip/hostname of node where Keystone is running
@@ -118,6 +119,7 @@ def initialize(host, admin_token, admin_email, admin_password,
     :param user: user to use to connect to the node where Keystone is running
     :param timeout: Total seconds to wait for keystone to be running
     :param poll_interval: Seconds to wait between keystone poll attempts
+    :param pki_setup: Boolean for running pki_setup conditionally
     """
 
     keystone = _create_admin_client(host, admin_token)
@@ -126,7 +128,8 @@ def initialize(host, admin_token, admin_email, admin_password,
     _create_tenants(keystone)
     _create_admin_user(keystone, admin_email, admin_password)
     _create_keystone_endpoint(keystone, host, region, ssl, public)
-    _perform_pki_initialization(host, user)
+    if pki_setup:
+        _perform_pki_initialization(host, user)
 
 
 def initialize_for_swift(host, admin_token):
@@ -272,10 +275,10 @@ def setup_endpoints(endpoints, public_host=None, region=None, client=None,
     }
 
     if not client:
-        client = ksclient.Client(username=os_username,
-                                 password=os_password,
-                                 tenant_name=os_tenant_name,
-                                 auth_url=os_auth_url)
+        LOG.warn('Creating client inline is deprecated, please pass '
+                 'the client as parameter.')
+        client = clients.get_keystone_client(
+            os_username, os_password, os_tenant_name, os_auth_url)
 
     # Setup roles first
     _setup_roles(client)
